# -*- coding: utf-8 -*-

"""Takes the input verse and produces verse lines in SLP1 transliteration."""

from __future__ import absolute_import, division, print_function, unicode_literals

import logging

from chandas.svat import read
from indic_transliteration import sanscript


def _preprocess_for_transliteration(text):
  """Clean up text before transliterating."""
  text = read.filters.process_crlf(text)
  text = read.filters.normalize_nfkc(text)
  text = read.filters.remove_control_characters(text)
  text = read.filters.process_html(text)
  # TODO(shreevatsa): Replace with a placeholder instead of removing entirely.
  text = read.filters.remove_verse_numbers(text)
  text = text.strip('\n')
  return text


def _transliterate_into_lines(orig_text):
  """Transliterates text to SLP1, removing all other characters."""
  pass_through = ' -?'
  cleaned_lines = []
  display_lines = []
  for orig_line in orig_text.splitlines():
    leading_verse_id = None
    match = read.split_gretil.MSS_LINE_INITIAL_REGEX.match(orig_line)
    if match:
      leading_verse_id = match.group(0)
      orig_line = orig_line[len(leading_verse_id):]
    (display_line, rejects) = sanscript.transliterate(orig_line, _to=sanscript.SLP1)

    ignore = r"""0123456789'".\/$&%{}|!’‘(),""" + 'ऽ।॥०१२३४५६७८९'
    read.filters.debug_rejected_characters(orig_line, rejects - set(ignore))
    cleaned_line = ''.join(c for c in display_line if c not in pass_through)
    # assert all(c in slp1.ALPHABET for c in cleaned_line), cleaned_line
    cleaned_lines.append(cleaned_line)
    display_lines.append(display_line)
  # while cleaned_lines and not cleaned_lines[-1]:
  #   cleaned_lines = cleaned_lines[:-1]
  #   display_lines = display_lines[:-1]
  return (cleaned_lines, display_lines)


def read_text(text):
  """The transliterated text from arbitrary input."""
  text = _preprocess_for_transliteration(text)
  (cleaned_lines, display_lines) = _transliterate_into_lines(text)

  debug_output = ['Input read as:']
  for (number, display_line) in enumerate(display_lines):
    transliterated = sanscript.transliterate(display_line)
    debug_output.append('Line %d: %s' % (number + 1, transliterated))
  debug_output.append('')
  logging.debug('\n'.join(debug_output))

  return (cleaned_lines, display_lines)
